%global desc This module provides function decorators which can be used to wrap \
a function such that it will be retried until some condition is met. \
It is meant to be of use when accessing unreliable resources with the \
potential for intermittent failures i.e. network resources and external \
APIs. Somewhat more generally, it may also be of use for dynamically \
polling resources for externally generated content.
%global srcname backoff

%if ! (0%{?fedora} || 0%{?rhel} > 7)
%bcond_without python2
%else
%bcond_with python2
%endif


Name:      python-%{srcname}
Version:   1.6.0
Release:   2%{?dist}
BuildArch: noarch

License: MIT
Summary: Python library providing function decorators for configurable backoff and retry
URL:     https://github.com/litl/%{srcname}
Source0: %{url}/archive/v%{version}/%{srcname}-%{version}.tar.gz
# https://github.com/litl/backoff/issues/56
# Patch from https://github.com/litl/backoff/pull/55
Patch0:  0000-Drop-support-for-Python-3.4-to-support-aiohttp-3.3.patch

%if %{with python2}
BuildRequires: python2-devel
BuildRequires: python2-pytest
%endif
BuildRequires: python%{python3_pkgversion}-devel
BuildRequires: python%{python3_pkgversion}-pytest
%if (0%{?fedora} || 0%{?rhel} > 7)
BuildRequires: python%{python3_pkgversion}-pytest-asyncio
%endif
%if 0%{?with_python3_other}
BuildRequires: python%{python3_other_pkgversion}-devel
BuildRequires: python%{python3_other_pkgversion}-pytest
%endif


%description
%{desc}


%if %{with python2}
%package -n python2-%{srcname}
Summary: %{summary}

%{?python_provide:%python_provide python2-%{srcname}}


%description -n python2-%{srcname}
%{desc}
%endif


%package -n python%{python3_pkgversion}-%{srcname}
Summary: %{summary}

%{?python_provide:%python_provide python%{python3_pkgversion}-%{srcname}}


%description -n python%{python3_pkgversion}-%{srcname}
%{desc}


%if 0%{?with_python3_other}
%package -n python%{python3_other_pkgversion}-%{srcname}
Summary: %{summary}

%{?python_provide:%python_provide python%{python3_other_pkgversion}-%{srcname}}


%description -n python%{python3_other_pkgversion}-%{srcname}
%{desc}
%endif


%prep
%autosetup -p1 -n %{srcname}-%{version}


%build
%if %{with python2}
%py2_build
%endif
%py3_build
%if 0%{?with_python3_other}
%py3_other_build
%endif


%install
%if %{with python2}
%py2_install
# Not used on Python 2 and fails byte compilation:
rm %{buildroot}%{python2_sitelib}/backoff/_async.py
%endif
%if 0%{?with_python3_other}
%py3_other_install
%endif
%py3_install


%check
%if %{with python2}
py.test-2.7 tests --ignore tests/python35
%else
py.test-%{python3_version} tests
%endif
%if 0%{?with_python3_other}
py.test-%{python3_other_version} tests
%endif


%if %{with python2}
%files -n python2-%{srcname}
%license LICENSE
%doc CHANGELOG.md
%doc README.rst
%{python2_sitelib}/%{srcname}
%{python2_sitelib}/*.egg-info
%endif


%files -n python%{python3_pkgversion}-%{srcname}
%license LICENSE
%doc CHANGELOG.md
%doc README.rst
%{python3_sitelib}/%{srcname}
%{python3_sitelib}/*.egg-info


%if 0%{?with_python3_other}
%files -n python%{python3_other_pkgversion}-%{srcname}
%license LICENSE
%doc CHANGELOG.md
%doc README.rst
%{python3_other_sitelib}/%{srcname}
%{python3_other_sitelib}/*.egg-info
%endif


%changelog
* Sat Feb 02 2019 Fedora Release Engineering <releng@fedoraproject.org> - 1.6.0-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_30_Mass_Rebuild

* Mon Jul 30 2018 Randy Barlow <bowlofeggs@fedoraproject.org> - 1.6.0-1
- Update to 1.6.0 (#1566766).
- https://github.com/litl/backoff/blob/v1.6.0/CHANGELOG.md
- Import a patch from an upstream pull request to solve a Python 3.7 compatibility issue (#1605610).

* Fri Jul 13 2018 Fedora Release Engineering <releng@fedoraproject.org> - 1.4.3-3
- Rebuilt for https://fedoraproject.org/wiki/Fedora_29_Mass_Rebuild

* Tue Jun 19 2018 Miro Hrončok <mhroncok@redhat.com> - 1.4.3-2
- Rebuilt for Python 3.7

* Thu Mar 08 2018 Randy Barlow <bowlofeggs@fedoraproject.org> - 1.4.3-1
- Initial release (#1553447).
